==> EntitySyncer-0.0.5-sources.jar: org/openzen/entitysyncer/live/field/LiveIntField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveInt;
import org.openzen.entitysyncer.structured.StructuredObject;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveIntField extends LiveBaseField implements LiveInt {
	private int value;
	
	public LiveIntField(int value) {
		this.value = value;
	}
	
	@Override
	public int get() {
		return value;
	}
	
	public void set(int value) {
		this.value = value;
		publish();
	}

	@Override
	public boolean asBoolValue() {
		return value != 0;
	}

	@Override
	public LiveInt asInt() {
		return this;
	}

	@Override
	public int asIntValue() {
		return value;
	}

	@Override
	public long asLongValue() {
		return value;
	}

	@Override
	public float asFloatValue() {
		return value;
	}

	@Override
	public double asDoubleValue() {
		return value;
	}

	@Override
	public String asStringValue() {
		return Integer.toString(value);
	}

	@Override
	public StructuredObject asObjectValue() {
		throw new ClassCastException("Cannot cast int to an object");
	}

	@Override
	public void setBool(boolean value) {
		set(value ? 1 : 0);
	}

	@Override
	public void setInt(int value) {
		set(value);
	}

	@Override
	public void setLong(long value) {
		set((int) value);
	}

	@Override
	public void setFloat(float value) {
		set((int) value);
	}

	@Override
	public void setDouble(double value) {
		set((int) value);
	}

	@Override
	public void setString(String value) {
		set(Integer.parseInt(value));
	}

	@Override
	public void setObject(StructuredObject value) {
		throw new ClassCastException("Cannot cast object to int");
	}
}

==> EntitySyncer-0.0.7-sources.jar: org/openzen/entitysyncer/live/field/LiveIntField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveInt;
import org.openzen.entitysyncer.structured.StructuredObject;
import org.openzen.entitysyncer.structured.definition.IntFieldType;
import org.openzen.entitysyncer.structured.definition.StructuredFieldType;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveIntField extends LiveBaseNumberField implements LiveInt {
	private int value;
	
	public LiveIntField(int value) {
		this.value = value;
	}
	
	@Override
	public int get() {
		return value;
	}
	
	public void set(int value) {
		this.value = value;
		publish();
	}
	
	@Override
	public void clear() {
		set(0);
	}
	
	@Override
	public StructuredFieldType getType() {
		return IntFieldType.INSTANCE;
	}

	@Override
	public boolean asBoolValue() {
		return value != 0;
	}

	@Override
	public LiveInt asInt() {
		return this;
	}

	@Override
	public int asIntValue() {
		return value;
	}

	@Override
	public long asLongValue() {
		return value;
	}

	@Override
	public float asFloatValue() {
		return value;
	}

	@Override
	public double asDoubleValue() {
		return value;
	}

	@Override
	public String asStringValue() {
		return Integer.toString(value);
	}

	@Override
	public StructuredObject asObjectValue() {
		throw new ClassCastException("Cannot cast int to an object");
	}

	@Override
	public void setBool(boolean value) {
		set(value ? 1 : 0);
	}

	@Override
	public void setInt(int value) {
		set(value);
	}

	@Override
	public void setLong(long value) {
		set((int) value);
	}

	@Override
	public void setFloat(float value) {
		set((int) value);
	}

	@Override
	public void setDouble(double value) {
		set((int) value);
	}

	@Override
	public void setString(String value) {
		set(Integer.parseInt(value));
	}

	@Override
	public void setObject(StructuredObject value) {
		throw new ClassCastException("Cannot cast object to int");
	}
}
